[![CII Best Practices](https://bestpractices.coreinfrastructure.org/projects/4862/badge)](https://bestpractices.coreinfrastructure.org/projects/4862)
[![Slack](https://img.shields.io/badge/Slack-%40lfaifoundation%2Fml--exchange-blue.svg?logo=slack&logoColor=red)](https://lfaifoundation.slack.com/archives/C0264LKNH63)


# Machine Learning eXchange (MLX)

**Data and AI Assets Catalog** 

Allows registration and search of Data and AI Assets:
 - AI pipelines and pipeline operators
 - Models
 - Datasets
 - Notebooks
 - Any other asset type by just specifying a JSON-Schema

This is Version 2 of MLX. MLX comes with its own backend but
integrations to HugginFace and other catalogs are on the roadmap.


## 1. How to Contribute

For information about adding new features, bug fixing, communication
or UI and API setup, refer to this [document](CONTRIBUTING.md).

## 2. Credits

MLX is supported by the EU’s Horizon Europe program under Grant Agreement number 101131841 and also received funding from the Swiss State Secretariat for Education, Research and Innovation (SERI) and the UK Research and Innovation (UKRI).
